﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics;
using System.ComponentModel;

namespace CheckAllAndCheckTrack
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            DataContext = new MainViewModel();
        }

        private void CheckBox_Click(object sender, RoutedEventArgs e)
        {
            (DataContext as MainViewModel).CheckUncheckAll((bool)(sender as CheckBox).IsChecked);
        }
    }


    public class MainViewModel : INotifyPropertyChanged
    {

        public MainViewModel()
        {
            Data = ChartData.GenerateData(20);

            foreach (ChartData data in Data)
            {
                data.PropertyChanged += data_PropertyChanged;
            }

            Data.CollectionChanged += (s, e) =>
                {
                    if (e.Action == System.Collections.Specialized.NotifyCollectionChangedAction.Add)
                        (e.NewItems[0] as ChartData).PropertyChanged += data_PropertyChanged;
                    if (e.Action == System.Collections.Specialized.NotifyCollectionChangedAction.Remove)
                        (e.NewItems[0] as ChartData).PropertyChanged -= data_PropertyChanged;

                };
            AllSelectedCount = Data.Where(d => d.Checked).Count();
        }

        void data_PropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            if (e.PropertyName.Equals("Checked"))
                AllSelectedCount = Data.Where(d => d.Checked).Count();
        }

        

        public void CheckUncheckAll(bool check)
        {
            foreach (ChartData item in Data)
            {
                item.Checked = check;
            }
        }

        int selectedCount;
        public int AllSelectedCount 
        {
            get
            {
                return selectedCount;
            }
            set
            {
                selectedCount = value;
                if (PropertyChanged != null)
                {
                    PropertyChanged(this, new PropertyChangedEventArgs("AllSelectedCount"));
                }
            }
        }

        public ObservableCollection<ChartData> Data { get; set; }

        public event PropertyChangedEventHandler PropertyChanged;
    }

    public class ChartData : INotifyPropertyChanged
    {
        public DateTime Date { get; set; }
        public double Value1 { get; set; }
        public double Value2 { get; set; }
        public double Value3 { get; set; }

        private bool isChecked;

        public bool Checked
        {
            get { return isChecked; }
            set 
            {
                isChecked = value;
                if (PropertyChanged != null)
                {
                    PropertyChanged(this, new PropertyChangedEventArgs("Checked"));
                }
            }
        }


        public static ObservableCollection<ChartData> GenerateData(int count)
        {
            ObservableCollection<ChartData> data = new ObservableCollection<ChartData>();

            Random r = new Random();

            ChartData data0 = new ChartData
            {
                Date = DateTime.Now,
                Value1 = r.Next(20, 40),
                Value2 = r.Next(20, 40),
                Value3 = r.Next(20, 40),
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartData dat = new ChartData
                {
                    Date = DateTime.Now.AddDays(i),
                    Checked = i % 2 == 0
                };

                if (r.NextDouble() > .5)
                {
                    dat.Value1 = data[i - 1].Value1 + r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 + r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 + r.NextDouble();
                }
                else
                {
                    dat.Value1 = data[i - 1].Value1 - r.NextDouble();
                    dat.Value2 = data[i - 1].Value2 - r.NextDouble();
                    dat.Value3 = data[i - 1].Value3 - r.NextDouble();
                }

                data.Add(dat);
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;
    }

}
